@@ -3,12 +3,12 @@
 #'Create a scatterplot showing the fit of the best climate window model through
 #'the biological data.
 #'@param dataset A dataframe containing information on all fitted climate 
-#'  windows. Output from \code{\link{climatewin}}.
+#'  windows. Output from \code{\link{slidingwin}}.
 #'@param bestmodel A model object. The strongest climate window model. Output 
-#'  from \code{\link{singlewin}} or \code{\link{climatewin}}.
+#'  from \code{\link{singlewin}} or \code{\link{slidingwin}}.
 #'@param bestmodeldata A dataframe with the data used to 
 #'  fit the strongest climate window model. Output from \code{\link{singlewin}} 
-#'  or \code{\link{climatewin}}.
+#'  or \code{\link{slidingwin}}.
 #'@return Returns a scatterplot with a fitted line to show the fit of the best 
 #'  model through the data.
 #'@author Liam D. Bailey and Martijn van de Pol
@@ -22,9 +22,9 @@
 #'single <- singlewin(xvar = list(Temp = MassClimate$Temp), 
 #'                    cdate = MassClimate$Date, bdate = Mass$Date, 
 #'                    baseline = lm(Mass ~ 1, data = Mass),
-#'                    furthest = 72, closest = 15, 
+#'                    range = c(72, 15), 
 #'                    stat = "mean", func = "lin", 
-#'                    type = "fixed", cutoff.day = 20, cutoff.month = 5, 
+#'                    type = "absolute", refday = c(20, 5), 
 #'                    cmissing = FALSE, cinterval = "day")
 #'            
 #'plotbest(dataset = MassOutput, bestmodel = single$BestModel,
@@ -46,7 +46,8 @@ plotbest <- function(dataset, bestmodel, bestmodeldata){
         theme(panel.grid.major = element_blank(),
               panel.grid.minor = element_blank(),
               axis.line = element_line(size = 0.25, colour = "black"),
-              plot.title = element_text(size = 16)) +
+              plot.title = element_text(size = 16),
+              panel.border = element_rect(colour = "black", fill = NA)) +
         ggtitle("Output of best model") +
         ylab("Biological variable")
     })
@@ -73,7 +74,8 @@ plotbest <- function(dataset, bestmodel, bestmodeldata){
             theme(panel.grid.major = element_blank(),
                   panel.grid.minor = element_blank(),
                   axis.line = element_line(size = 0.25, colour = "black"),
-                  plot.title = element_text(size = 16)) +
+                  plot.title = element_text(size = 16),
+                  panel.border = element_rect(colour = "black", fill = NA)) +
             ggtitle("Output of best model") +
             ylab("Biological variable") +    
             if (dataset$Function[1] == "log"){
@@ -104,7 +106,7 @@ plotbest <- function(dataset, bestmodel, bestmodeldata){
         newdat[, 1] <- xval
         #The first column of the matrix will always be the same as the xval
         for(cols in 2:(ncol(bestmodeldata) - col)){ #This will go through every column except for Yvar
-          if(is.character(bestmodeldata[, cols]) == FALSE){ #If the variable is not categorical then take the mean
+          if(is.factor(bestmodeldata[, cols]) == FALSE){ #If the variable is not categorical then take the mean
             newdat[, cols] <- mean(bestmodeldata[, cols])
           } else { #If it is categorical, simply take the first category
             newdat[, cols] = bestmodeldata[1, cols]          
@@ -120,7 +122,8 @@ plotbest <- function(dataset, bestmodel, bestmodeldata){
             theme(panel.grid.major = element_blank(),
                   panel.grid.minor = element_blank(),
                   axis.line = element_line(size = 0.25, colour = "black"),
-                  plot.title = element_text(size = 16)) +
+                  plot.title = element_text(size = 16),
+                  panel.border = element_rect(colour = "black", fill = NA)) +
             ggtitle("Output of best model") +
             ylab("Biological variable") +    
             if (dataset$Function[1] == "log"){
@@ -146,7 +149,8 @@ plotbest <- function(dataset, bestmodel, bestmodeldata){
             theme(panel.grid.major = element_blank(),
                   panel.grid.minor = element_blank(),
                   axis.line = element_line(size = 0.25, colour = "black"),
-                  plot.title = element_text(size = 16)) +
+                  plot.title = element_text(size = 16),
+                  panel.border = element_rect(colour = "black", fill = NA)) +
             ggtitle("Output of best model") +
             ylab("Biological variable") +    
             if (dataset$Function[1] == "log"){
@@ -177,7 +181,7 @@ plotbest <- function(dataset, bestmodel, bestmodeldata){
         newdat[, 1] <- xval
         #The first column of the matrix will always be the same as the xval
         for(cols in 2:(ncol(bestmodeldata) - col)){ #This will go through every column except for Yvar
-          if(is.character(bestmodeldata[, cols]) == FALSE){ #If the variable is not categorical then take the mean
+          if(is.factor(bestmodeldata[, cols]) == FALSE){ #If the variable is not categorical then take the mean
             newdat[, cols] <- mean(bestmodeldata[, cols])
           } else { #If it is categorical, simply take the first category
             newdat[, cols] = bestmodeldata[1, cols]          
@@ -193,7 +197,8 @@ plotbest <- function(dataset, bestmodel, bestmodeldata){
             theme(panel.grid.major = element_blank(),
                   panel.grid.minor = element_blank(),
                   axis.line = element_line(size = 0.25, colour = "black"),
-                  plot.title = element_text(size = 16)) +
+                  plot.title = element_text(size = 16),
+                  panel.border = element_rect(colour = "black", fill = NA)) +
             ggtitle("Output of best model") +
             ylab("Biological variable") +    
             if (dataset$Function[1] == "log"){
