@@ -1,10 +1,10 @@
-#'Plot the opening and closing point of best climate windows
+#'Plot the start and end time of best climate windows
 #'
-#'Visualise the opening and closing point for a subset of best climate windows.
+#'Visualise the start and end time for a subset of best climate windows.
 #'@param dataset A dataframe containing information on all fitted climate
-#'  windows. Output from \code{\link{climatewin}}.
+#'  windows. Output from \code{\link{slidingwin}}.
 #'@param cw Cumulative model weight used to subset the group of best models.
-#'@return Creates two boxplots showing the opening and closing point for a subset
+#'@return Creates two boxplots showing the start and end time for a subset
 #'  of best climate windows. Best climate windows make up the
 #'  cumulative model weight equivalent to the value of cw.
 #'@author Liam D. Bailey and Martijn van de Pol
@@ -26,10 +26,10 @@ plotwin <- function(dataset, cw = 0.95){
   dataset$cw <- as.numeric(cumsum(dataset$ModWeight) <= cw)
   datasetcw  <- subset(dataset, cw == 1)
   
-  keep=c("closest", "WindowClose", "WindowOpen")
+  keep=c("Closest", "WindowClose", "WindowOpen")
   
   datasetcw                  <- datasetcw[keep]
-  datasetcw                  <- melt(datasetcw, id = "closest")
+  datasetcw                  <- melt(datasetcw, id = "Closest")
   datasetcw$variable         <- factor(datasetcw$variable, levels = c("WindowOpen", "WindowClose"))
   levels(datasetcw$variable) <- c("Window Open", "Window Close")
   
@@ -47,8 +47,9 @@ plotwin <- function(dataset, cw = 0.95){
             panel.grid.minor = element_blank(),
             axis.line = element_line(size = 0.25, colour = "black"),
             axis.text.y = element_text(angle = 90, hjust = 0.5,size = 10),
-            plot.title = element_text(size = 16))+
-      ggtitle(paste("Climate window range for top \n", (cw*100), "% of model weights"))+
+            plot.title = element_text(size = 16),
+            panel.border = element_rect(colour = "black", fill = NA))+
+      ggtitle(paste("Climate window range for \n", (cw*100), "% confidence set"))+
       xlab("")+
       ylab("Climate window")
   })
